==> bodhi-cli-0.6.16.tgz: package/lib/environment.js <==
var _ = require('./utils');
var Client = require('rbc-rest-client');


function Environment(name, attr){
    this.name         = name;
    this.type         = 'Environment';
    this.attributes   = _.extend({}, attr);
    this.project      = null;
}

Environment.prototype = {

    isBound: function(){
        return this.project != null;
    }

    , getProject: function(){
        return this.project;
    }

    , setProject: function(project){
        this.project = project;
        return this
    }

    , getAttributes: function(){
        return this.attributes;
    }

    , getName: function(){
        return this.name;
    }

    , getUri: function(){
        return this.attributes.uri;
    }

    , getUser: function(){
        return this.attributes.user;
    }

    , getPassword: function(){
        return this.attributes.password;
    }

    , getNamespace: function(){
        return this.attributes.namespace;
    }

    , setUri: function(value){
        this.attributes.uri = value;
        return this;
    }

    , setUser: function(value){
        this.attributes.user = value;
        return this;
    }

    , setPassword: function(value){
        this.attributes.password = value;
        return this;
    }

    , setNamespace: function(value){
        this.attributes.namespace = value;
        return this;
    }

    , has: function(key){
        return this.attributes[key] != null;
    }

    , get: function(key){
        return this.attributes[key];
    }

    , set: function(key, value){
        this.attributes[key] = value;
        return this;
    }

    , unset: function(key){
        delete this.attributes[key];
        return this;
    }

    , patch: function(patch){
        if(patch) this.attributes = _.extend(this.attributes, patch);
        return this;
    }

    , createClient: function(){
        return new Client(this.getAttributes());
    }

    , save: function(callback){
        if(this.isBound() && this.getProject().hasEnvironment(this.name)){
            this.project.setEnvironment(this);
            this.project.save(callback);
        }
    }

    , destroy: function(callback){
        if(this.isBound()){
            this.project.removeEnvironment(this.name)
            this.project.save(callback);
        }
    }

    , toString   : function(){
        return this.type + "[" + this.getName() + "]";
    }

    , toJSON     : function(){
        return _.toDelimitedJson(this.attributes);
    }

    , toJson     : this.toJSON
}

module.exports = Environment;

==> bodhi-cli-0.7.10.tgz: package/lib/environment.js <==
var _ = require('./utils');
var Client = require('rbc-rest-client');


function Environment(name, attr){
    this.name         = name;
    this.type         = 'Environment';
    this.attributes   = _.extend({}, attr);
    this.project      = null;
}

Environment.prototype = {

    isBound: function(){
        return this.project != null;
    }

    , getProject: function(){
        return this.project;
    }

    , setProject: function(project){
        this.project = project;
        return this
    }

    , getAttributes: function(){
        return this.attributes;
    }

    , getName: function(){
        return this.name;
    }

    , getUri: function(){
        return this.attributes.uri;
    }

    , getUser: function(){
        return this.attributes.username;
    }

    , getPassword: function(){
        return this.attributes.password;
    }

    , getNamespace: function(){
        return this.attributes.namespace;
    }

    , setUri: function(value){
        this.attributes.uri = value;
        return this;
    }

    , setUser: function(value){
        this.attributes.user = value;
        return this;
    }

    , setPassword: function(value){
        this.attributes.password = value;
        return this;
    }

    , setNamespace: function(value){
        this.attributes.namespace = value;
        return this;
    }

    , has: function(key){
        return this.attributes[key] != null;
    }

    , get: function(key){
        return this.attributes[key];
    }

    , set: function(key, value){
        this.attributes[key] = value;
        return this;
    }

    , unset: function(key){
        delete this.attributes[key];
        return this;
    }

    , patch: function(patch){
        if(patch) this.attributes = _.extend(this.attributes, patch);
        return this;
    }

    , createClient: function(){
        return new Client(this.getAttributes());
    }

    , save: function(callback){
        if(this.isBound() && this.getProject().hasEnvironment(this.name)){
            this.project.setEnvironment(this);
            this.project.save(callback);
        }
    }

    , destroy: function(callback){
        if(this.isBound()){
            this.project.removeEnvironment(this.name)
            this.project.save(callback);
        }
    }

    , toString   : function(){
        return this.type + "[" + this.getName() + "]";
    }

    , toJSON     : function(){
        return _.toDelimitedJson(this.attributes);
    }

    , toJson     : this.toJSON
}

module.exports = Environment;
